@@ -4,7 +4,7 @@
 # For usual compilation do
 #     cargo build --release
 # or read all possible installation solutions on
-# https://dystroy.org/broot/documentation/installation/
+# https://dystroy.org/broot/install
 
 H1="\n\e[30;104;1m\e[2K\n\e[A" # style first header
 H2="\n\e[30;104m\e[1K\n\e[A" # style second header
@@ -76,14 +76,7 @@ echo "   Done"
 
 # add a summary of content
 echo '
-This archive contains pre-compiled binaries:
-
-x86_64-linux/broot : standard Linux, clipboard support, most optimized
-aarch64-linux-android/broot : Android, clipboard support
-x86_64-unknown-linux-gnu : Linux/glibc, no clipboard support, compatible with older GLIBC
-x86_64-unknown-linux-musl : Linux/musl, no clipboard support
-armv7-unknown-linux-gnueabihf : Raspberry | no clipboard support
-x86_64-pc-windows-gnu : Windows 10+, clipboard support
+This archive contains pre-compiled binaries.
 
 For more information, or if you prefer to compile yourself, see https://dystroy.org/broot/install
 ' > build/install.md
